Eyes Selenium Python SDK
========================
|pypi version| |pypi downloads| |Black Formatter|

Applitools Eyes SDK For Selenium Python WebDriver

Installation
------------

Install the eyes-selenium SDK.

::

    pip install eyes-selenium

Usage
-----

Please check the applitools website for usage instructions:

-  Selenium Python example:
   https://applitools.com/resources/tutorial/selenium/python#step-2

-  Python Appium native example:
   https://applitools.com/resources/tutorial/appium/native\_python#step-2

-  Python Appium web example:
   https://applitools.com/resources/tutorial/appium/python#step-2

.. |Black Formatter| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black
.. |pypi version| image:: https://img.shields.io/pypi/v/eyes-selenium
   :target: https://pypi.org/project/eyes-selenium/
.. |pypi downloads| image:: https://img.shields.io/pypi/dw/eyes-selenium
   :target: https://pypi.org/project/eyes-selenium/
